@@ -131,8 +131,10 @@ class WorkspacesHandler(APIHandler):
                 except Exception as e:
                     raise web.HTTPError(500, str(e))
         else:
-            raise web.HTTPError(404, 'Workspace %r (%r) not found' %
-                                     (space_name, slug))
+            id = (space_name if space_name.startswith('/')
+                             else '/' + space_name)
+            workspace = dict(data=dict(), metadata=dict(id=id))
+            return self.finish(json.dumps(workspace))
 
     @json_errors
     @web.authenticated
@@ -161,6 +163,7 @@ class WorkspacesHandler(APIHandler):
         metadata_id = workspace['metadata']['id']
         metadata_id = (metadata_id if metadata_id.startswith('/')
                        else '/' + metadata_id)
+        metadata_id = urllib.parse.unquote(metadata_id)
         if metadata_id != '/' + space_name:
             message = ('Workspace metadata ID mismatch: expected %r got %r'
                        % (space_name, metadata_id))
